==> apache-mynewt-core-1.13.0.tgz: apache-mynewt-core-1.13.0/hw/usb/tinyusb/shell/src/tinyusb_cli.c <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#include <os/mynewt.h>
#include <shell/shell.h>
#include <tinyusb/tinyusb.h>
#include <device/usbd.h>
#include <tusb.h>

static int
usb_cli_start_cmd(const struct shell_cmd *cmd, int argc, char **argv,
                  struct streamer *streamer)
{
    if (!tusb_inited()) {
        tinyusb_start();
    } else if (!tud_connected()) {
        tud_connect();
    }

    return 0;
}

static int
usb_cli_stop_cmd(const struct shell_cmd *cmd, int argc, char **argv,
                  struct streamer *streamer)
{
    if (tud_connected()) {
        tud_disconnect();
    }

    return 0;
}

static const struct shell_cmd usb_cli_commands[] = {
    SHELL_CMD_EXT("start", usb_cli_start_cmd, NULL),
    SHELL_CMD_EXT("stop", usb_cli_stop_cmd, NULL),
    { },
};

int
tinyusb_cli_init(void)
{
    shell_register("usb", usb_cli_commands);

    return 0;
}

==> apache-mynewt-core-1.14.0.tgz: apache-mynewt-core-1.14.0/hw/usb/tinyusb/shell/src/tinyusb_cli.c <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

#include <os/mynewt.h>
#include <shell/shell.h>
#include <tinyusb/tinyusb.h>
#include <device/usbd.h>
#include <tusb.h>

static int
usb_cli_start_cmd(const struct shell_cmd *cmd, int argc, char **argv,
                  struct streamer *streamer)
{
    if (!tusb_inited()) {
        tinyusb_start();
    } else if (!tud_connected()) {
        tud_connect();
    }

    return 0;
}

static int
usb_cli_stop_cmd(const struct shell_cmd *cmd, int argc, char **argv,
                  struct streamer *streamer)
{
    if (tud_connected()) {
        tud_disconnect();
    }

    return 0;
}

static const struct shell_cmd usb_cli_commands[] = {
    SHELL_CMD_EXT("start", usb_cli_start_cmd, NULL),
    SHELL_CMD_EXT("stop", usb_cli_stop_cmd, NULL),
};

SHELL_MODULE_WITH_TABLE(usb, usb_cli_commands)
